// You can import API functions like this from D3.js.
import { csv } from 'd3';

// Data set URI
const csvUrl =
  'https://raw.githubusercontent.com/Rastanne/Activity7_Datasets/main/Ebola_affected_people.csv';

// Function to fetch data from the URI
const fetchData = async () => {
  const data = await csv(csvUrl);
  console.log('Raw data:', data); // Log the raw data

  // Aggregate data by AreaName
  const aggregatedData = d3
    .nest()
    .key((d) => d.Country)
    .rollup((values) =>
      d3.sum(values, (d) => +d['Affected_People']),
    )
    .entries(data)
    .map((d) => ({ Country: d.key, Total: d.value }));
  console.log('Aggregated data:', aggregatedData); // Log the aggregated data

  return aggregatedData;
};

// Function to render the pie chart with the processed data
const renderPieChart = (aggregatedData) => {
  console.log('Data to render:', aggregatedData); // Log data received by the render function
  const svg = d3.select('svg');
  const width = +svg.attr('width');
  const height = +svg.attr('height');
  const radius = Math.min(width, height) / 2;

  const color = d3.scaleOrdinal(d3.schemeCategory10);
  //const color = d3.scaleOrdinal([
  // '#FFD700',
  // '#018670',
  // '#B22222',
  // '#8dc63f',
  // '#f58026',
  // '#00b5cc',
  //]);
  //const color = d3.scaleOrdinal(d3.schemePastel2);

  const pie = d3
    .pie()
    .value((d) => d.Total)
    .sort(null);

  const path = d3
    .arc()
    .outerRadius(radius - 10)
    .innerRadius(0);

  const label = d3
    .arc()
    .outerRadius(radius - 40)
    .innerRadius(radius - 40);

  const tooltip = d3.select('.tooltip');

  const arc = svg
    .append('g')
    .attr(
      'transform',
      `translate(${width / 2}, ${height / 2})`,
    )
    .selectAll('.arc')
    .data(pie(aggregatedData))
    .enter()
    .append('g')
    .attr('class', 'arc');

  arc
    .append('path')
    .attr('d', path)
    .attr('fill', (d) => color(d.data.Country))
    .on('mouseover', function (d) {
      console.log('Current data:', d); // Check the structure of 'd'
      // Use 'aggregatedData' here to calculate the total when needed
      const total = d3.sum(aggregatedData, (d) => d.Total);
      tooltip
        .transition()
        .duration(200)
        .style('opacity', 1);
      tooltip
        .html(
          `${d.data.Country}<br/>${d.data.Total} (${((d.data.Total / total) * 100).toFixed(2)}%)`,
        )
        .style('left', d3.event.pageX + 10 + 'px')
        .style('top', d3.event.pageY + 10 + 'px')
        .style('opacity', 1); // Make sure the tooltip is visible
    })
    .on('mouseout', function () {
      tooltip
        .transition()
        .duration(500)
        .style('opacity', 0);
    });

  // Add the legend
  const legend = svg
    .append('g')
    .attr(
      'transform',
      'translate(' + (width - 240) + ',' + 30 + ')',
    )
    .selectAll('.legend')
    .data(pie(aggregatedData))
    .enter()
    .append('g')
    .attr('class', 'legend')
    .attr('transform', (d, i) => `translate(0,${i * 20})`);

  legend
    .append('rect')
    .attr('width', 18)
    .attr('height', 18)
    .style('fill', (d) => color(d.data.Country));

  legend
    .append('text')
    .attr('x', 24)
    .attr('y', 9)
    .attr('dy', '.35em')
    .text(
      (d) =>
        `${d.data.Country} (${((d.data.Total / d3.sum(aggregatedData, (d) => d.Total)) * 100).toFixed(2)}%)`,
    );

  console.log('SVG after appending paths:', svg.node()); // Log the SVG node to see if paths are appended
};

// Main function to run the pie chart creation
const run = async () => {
  const processedData = await fetchData();
  renderPieChart(processedData);
};

run();
